<?php
	// Load config file and store variables as keys of $config[]
	$configfile = file("./system/config.txt");
	foreach ($configfile as $line) {
		if (strpos($line, "=")) {
			$key = substr($line, 0, strpos($line, "="));
			$value = trim(substr($line, strpos($line, "=") + 1));
			$config[$key] = $value;
		}
	}
	
	// Load POST variables
	$regadmin = ""; if (array_key_exists('regadmin', $_POST)) $regadmin = $_POST['regadmin'];
	$regemail = ""; if (array_key_exists('regemail', $_POST)) $regemail = $_POST['regemail'];
	$reguser = ""; if (array_key_exists('reguser', $_POST)) $reguser = $_POST['reguser'];
	$regpwd = ""; if (array_key_exists('regpwd', $_POST)) $regpwd = $_POST['regpwd'];
	$regpwdconf = ""; if (array_key_exists('regpwdconf', $_POST)) $regpwdconf = $_POST['regpwdconf'];

	// Check for error: Missing fields
	$errortext = "";
	if ($regemail == "") $errortext .= "email, ";
	if ($reguser == "") $errortext .= "archive name, ";
	if ($regpwd == "") $errortext .= "password, ";
	if ($regpwdconf == "") $errortext .= "confirm password, ";

	if ($errortext != "") $errortext = "Missing required fields: " . $errortext;
	if (substr($errortext, -2) == ", ") $errortext = substr($errortext, 0, strlen($errortext) - 2) . ".";
	
	// Check for error: Passwords do not match
	if ($regpwd != $regpwdconf && $errortext == "") $errortext = "Passwords do not match.";
	
	// Check for error: Password is illegal
	if (strpos($regpwd, chr(13)) || strpos($regpwd, chr(10))) $errortext = "Password contains an illegal character.";

	// Check for error: reCAPTCHA failed
	if ($config['reCAPTCHA-publickey'] != "") {
		require_once('recaptchalib.php');
		$privatekey = $config['reCAPTCHA-privatekey'];
		$resp = recaptcha_check_answer ($privatekey, $_SERVER["REMOTE_ADDR"], $_POST["recaptcha_challenge_field"], $_POST["recaptcha_response_field"]);

		if (!$resp->is_valid && $errortext == "") {
			$errortext = "Please enter the text displayed in the box to the right (to verify that you are human.)";
		}
	}
	
	// Check for error: Email is illegal
	if (strpos($regpwd, chr(13)) || strpos($regpwd, chr(10))) $errortext = "Email contains an illegal character.";

	// Check for error: Archive name already exists
	if (file_exists("./boxes/$reguser") && $reguser != "") $errortext = "The archive name you specified is already taken. Please use a different one.";
	
	// Check for error: Archive name is illegal
	if (strpos($reguser, '.') || strpos($reguser, chr(13)) || strpos($reguser, chr(10)) || strpos($reguser, ' ') || strpos($reguser, '/') || strpos($reguser, '\\') || strpos($reguser, '!') || strpos($reguser, '*') || strpos($reguser, ':') || strpos($reguser, '?') || strpos($reguser, '"') || strpos($reguser, '<') || strpos($reguser, '>') || strpos($reguser, '|')) $errortext = "Archive name must be a single word with only letters, numbers, and underscores.";
	
	// Check for error: Wrong admin password
	if ($config['registrationpassword'] != "" && $regadmin != $config['registrationpassword']) $errortext = "An administrator password is required to register new accounts on this server.";

	// Redirect on error
	if ($errortext != "") {
		header("Location: index.php?err=" . urlencode($errortext) . "&regadmin=" . urlencode($regadmin) . "&regemail=" . urlencode($regemail) . "&reguser=" . urlencode($reguser) . "&regpwd=" . urlencode($regpwd) . "&regpwdconf=" . urlencode($regpwdconf));
		exit;
	}
	
	// Create account
	mkdir("./boxes/$reguser", 0700);
	file_put_contents("./boxes/$reguser/CONFIG.TXT", "");
	file_put_contents("./boxes/$reguser/FILES.DAT", "");
	
	$userlist = file_get_contents("./system/users.txt");
	$userlist .= "\r\n" . $reguser . "=" . $regpwd;
	file_put_contents("./system/users.txt", $userlist);
	
	$emaillist = file_get_contents("./system/emails.txt");
	$emaillist .= "\r\n" . $reguser . "=" . $regemail;
	file_put_contents("./system/emails.txt", $emaillist);

	// Success - redirect to instructions
	header("Location: instructions.php?&a=" . urlencode($reguser) . "&p=" . urlencode($regpwd));
?>